@@ -3,6 +3,13 @@
 
 #include <iostream>
 
-void showHelp(std::string_view option);
+
+class Help {
+
+public:
+
+    static void showHelp(const std::string& option);
+
+};
 
 #endif //LIBPDFTOIMAGE_HELP_H
\ No newline at end of file
